clear
clear matrix
drop _all
set mem 512m

use "C:\BellemareNovakAJAEContractFarming.dta", clear

label variable soudure "Duration of Hungry Season"
label variable cf "Contract Farming Participant"
label variable hhsize "Household Size"
label variable depr "Dependency Ratio"
label variable female "Female"
label variable migrant "Migrant"
label variable age "Age"
label variable educ "Education"
label variable ag_exp "Agricultural Experience"
label variable fady "Fady Days"
label variable wrk_cap "Working Capital" 
label variable assets "Assets"
label variable k1_0 "No Any Investment"
label variable k1_1 "Yes to $12.50 Investment"
label variable k1_2 "Yes to $25.00 Investment"
label variable k1_3 "Yes to $37.50 Investment"
label variable k1_4 "Yes to $50.00 Investment"
label variable k1_5 "Yes to $62.50 Investment"
label variable k1_6 "Yes to $75.00 Investment"

* Table 1 *

mean soudure cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 wtp if cf==0 [pweight=weight]
mean soudure cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 wtp if cf==1 [pweight=weight]

sort codemen 

drop _merge
merge codemen using "C:\FoodCrops.dta" 

drop _merge

ttest soudure, by(cf)

gen cf_food_crop_share = cf*food_crop_share
gen cf_rice_crop_share = cf*rice_crop_share

* Figures 1 and 2 *

stset soudure [pweight=weight]
sts graph, by(cf) title(Kaplan-Meier Estimates) xtitle(Duration of Hungry Season (Months)) ytitle(Proportion of Households) legend(lab("1" CF Nonparticipant) lab("2" CF Participant)) ///
	plot1opts(lpattern(dash)) ///
	plot2opts(lpattern(solid)) graphregion(color(white)) bgcolor(white)
	
kdensity soudure if cf==0, w(1) epanechnikov addplot(kdensity soudure, w(1) epanechnikov lpattern(dash)) title(Distribution of Hungry Season Duration) legend(label(1 "Does Not Participate in CF")) legend(label(2 "Participates in CF")) graphregion(color(white)) bgcolor(white)

* Table 2a *

xi: reg soudure cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 [pweight=weight]

stcox cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6

streg cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6, distribution(weibull)


* Table 2b *

xi: reg soudure cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight]
test k1_1 k1_2 k1_3 k1_4 k1_5 k1_6

stcox cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6
test k1_1 k1_2 k1_3 k1_4 k1_5 k1_6

streg cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6, distribution(weibull)
test k1_1 k1_2 k1_3 k1_4 k1_5 k1_6


* Treatment Heterogeneity *

gen kids = dem_m_u10 + dem_m_10_14 + dem_f_u10 + dem_f_10_14
gen kids_m = dem_m_u10 + dem_m_10_14
gen kids_f = dem_f_u10 + dem_f_10_14
gen cf_kids = cf*kids
gen cf_kids_m = cf*kids_m
gen cf_kids_f = cf*kids_f

* Table 3 *

xi: reg soudure cf cf_kids kids hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight]
stcox cf cf_kids kids hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6
streg cf cf_kids kids hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6, distribution(weibull)

* Table 4 *

xi: reg soudure cf cf_kids_f cf_kids_m kids_f kids_m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight]
stcox cf cf_kids_f cf_kids_m kids_f kids_m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6
streg cf cf_kids_f cf_kids_m kids_m kids_f hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6, distribution(weibull)

* Table 5 *

probit cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6
predict propensity

* Figure 3 *
twoway hist propensity if cf==1, fcolor(none) lcolor(black) lpattern(solid) || hist propensity if cf==0, fcolor(none) lcolor(black) lpattern(shortdash) xtitle(Propensity Score) title(Distribution of Propensity Scores) legend(order(1 "CF Participant" 2 "CF Nonparticipant")) graphregion(color(white)) legend(off)

* Table 6 *
* Note: Standard errors reported in the paper were calculated using Stata version 10. Readers using newer versions of Stata may calculate slightly different standard errors.
/* 1 neighbor matching */
psmatch2 cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6, out(soudure) ate cal(.01) ai(3)

/* 3 Nearest Neighbors */
psmatch2 cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6, out(soudure) n(3) ate cal(.01) ai(3) 

/* 3 Nearest Neighbors and small caliper*/
psmatch2 cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6, out(soudure) n(3) cal(.001) ate ai(3)


* Table 7 *

xi: qreg soudure cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 
test k1_1 k1_2 k1_3 k1_4 k1_5 k1_6

xi: rreg soudure cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 
test k1_1 k1_2 k1_3 k1_4 k1_5 k1_6


* Appendix *

clear
clear matrix
drop _all
set mem 512m

use "C:\BellemareNovakAJAEContractFarming.dta", clear


label variable soudure "Duration of Hungry Season"
label variable cf "Contract Farming Participant"
label variable hhsize "Household Size"
label variable depr "Dependency Ratio"
label variable female "Female"
label variable migrant "Migrant"
label variable age "Age"
label variable educ "Education"
label variable ag_exp "Agricultural Experience"
label variable fady "Fady Days"
label variable wrk_cap "Working Capital" 
label variable assets "Assets"
label variable k1_0 "No Any Investment"
label variable k1_1 "Yes to $12.50 Investment"
label variable k1_2 "Yes to $25.00 Investment"
label variable k1_3 "Yes to $37.50 Investment"
label variable k1_4 "Yes to $50.00 Investment"
label variable k1_5 "Yes to $62.50 Investment"
label variable k1_6 "Yes to $75.00 Investment"

mean soudure cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 wtp [pweight=weight]
ttest soudure, by(cf)

stset soudure

gen draw = 1 if k1_invest==12.5
replace draw = 2 if k1_invest==25
replace draw = 3 if k1_invest==37.5
replace draw = 4 if k1_invest==50
replace draw = 5 if k1_invest==62.5
replace draw = 6 if k1_invest==75 


foreach i in 1 2 3 4 5 6 {

gen k1`i'm = k1_`i' if draw==`i'

}



impute k11m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6, gen(k11mi)
impute k12m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6, gen(k12mi)
impute k13m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6, gen(k13mi)
impute k14m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6, gen(k14mi)
impute k15m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6, gen(k15mi)
impute k16m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6, gen(k16mi)

* Table A2 *

set seed 123456789
xi: reg soudure cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi, vce(bootstrap, reps(500))

set seed 123456789
stcox cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi, vce(bootstrap, reps(500))

set seed 123456789
streg cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi, distribution(weibull) vce(bootstrap, reps(500))


* Treatment Heterogeneity *

gen kids = dem_m_u10 + dem_m_10_14 + dem_f_u10 + dem_f_10_14
gen kids_m = dem_m_u10 + dem_m_10_14
gen kids_f = dem_f_u10 + dem_f_10_14
gen cf_kids = cf*kids
gen cf_kids_m = cf*kids_m
gen cf_kids_f = cf*kids_f

* Table A3 *

set seed 123456789
xi: reg soudure cf cf_kids kids hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi, vce(bootstrap, reps(500))

set seed 123456789
stcox cf cf_kids kids hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi, vce(bootstrap, reps(500))

set seed 123456789
streg cf cf_kids kids hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi, distribution(weibull) vce(bootstrap, reps(500))


* Table A4 *

set seed 123456789
xi: reg soudure cf cf_kids_f cf_kids_m kids_f kids_m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi, vce(bootstrap, reps(500))

set seed 123456789
stcox cf cf_kids_f cf_kids_m kids_f kids_m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi, vce(bootstrap, reps(500))

set seed 123456789
streg cf cf_kids_f cf_kids_m kids_f kids_m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi, distribution(weibull) vce(bootstrap, reps(500))


clear
clear matrix
drop _all
set mem 512m

use "C:\BellemareNovakAJAEContractFarming.dta", clear

label variable soudure "Duration of Hungry Season"
label variable cf "Contract Farming Participant"
label variable hhsize "Household Size"
label variable depr "Dependency Ratio"
label variable female "Female"
label variable migrant "Migrant"
label variable age "Age"
label variable educ "Education"
label variable ag_exp "Agricultural Experience"
label variable fady "Fady Days"
label variable wrk_cap "Working Capital" 
label variable assets "Assets"
label variable k1_0 "No Any Investment"
label variable k1_1 "Yes to $12.50 Investment"
label variable k1_2 "Yes to $25.00 Investment"
label variable k1_3 "Yes to $37.50 Investment"
label variable k1_4 "Yes to $50.00 Investment"
label variable k1_5 "Yes to $62.50 Investment"
label variable k1_6 "Yes to $75.00 Investment"

stset soudure [pweight=weight]

gen draw = 1 if k1_invest==12.5
replace draw = 2 if k1_invest==25
replace draw = 3 if k1_invest==37.5
replace draw = 4 if k1_invest==50
replace draw = 5 if k1_invest==62.5
replace draw = 6 if k1_invest==75 


foreach i in 1 2 3 4 5 6 {

gen k1`i'm = k1_`i' if draw==`i'

}



impute k11m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6, gen(k11mi)
impute k12m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6, gen(k12mi)
impute k13m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6, gen(k13mi)
impute k14m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6, gen(k14mi)
impute k15m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6, gen(k15mi)
impute k16m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6, gen(k16mi)

* Table A5 *

set seed 123456789
xi: reg soudure cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi [pweight=weight]

set seed 123456789
stcox cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi

set seed 123456789
streg cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi, distribution(weibull)


* Treatment Heterogeneity *

gen kids = dem_m_u10 + dem_m_10_14 + dem_f_u10 + dem_f_10_14
gen kids_m = dem_m_u10 + dem_m_10_14
gen kids_f = dem_f_u10 + dem_f_10_14
gen cf_kids = cf*kids
gen cf_kids_m = cf*kids_m
gen cf_kids_f = cf*kids_f

* Table A6 *

set seed 123456789
xi: reg soudure cf cf_kids kids hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi [pweight=weight]

set seed 123456789
stcox cf cf_kids kids hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi

set seed 123456789
streg cf cf_kids kids hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi, distribution(weibull)

* Table A7 *

set seed 123456789
xi: reg soudure cf cf_kids_f cf_kids_m kids_f kids_m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi [pweight=weight]

set seed 123456789
stcox cf cf_kids_f cf_kids_m kids_f kids_m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi

set seed 123456789
streg cf cf_kids_f cf_kids_m kids_f kids_m hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi, distribution(weibull)



* Table A8 *

xi: treatreg soudure hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 [pweight=weight], treat(cf = hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6) first

xi: treatreg soudure hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 [pweight=weight], treat(cf = hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k11mi k12mi k13mi k14mi k15mi k16mi) first




gen wtp1 = (k1_1 == 1) | (k1_2 == 1) | (k1_3 == 1) | (k1_4 == 1) | (k1_5 == 1) | (k1_6 == 1)
gen wtp2 = (k1_2 == 1) | (k1_3 == 1) | (k1_4 == 1) | (k1_5 == 1) | (k1_6 == 1)
gen wtp3 = (k1_3 == 1) | (k1_4 == 1) | (k1_5 == 1) | (k1_6 == 1)
gen wtp4 = (k1_4 == 1) | (k1_5 == 1) | (k1_6 == 1)
gen wtp5 = (k1_5 == 1) | (k1_6 == 1)
gen wtp6 = (k1_6 == 1)

mean wtp1-wtp6

* Table A9 *

xi: reg soudure cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 wtp1-wtp6 [pweight=weight]

stcox cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 wtp1-wtp6

streg cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 wtp1-wtp6, distribution(weibull)


* Note: Balance statistics reported in Tables A10-A12 of the Appendix were calculated using Stata version 10. Readers using newer versions of Stata may calculate slightly different balance statistics.
* Table A10 - 1 neighbor matching */
psmatch2 cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6, out(soudure) ate cal(.01) ai(3)
pstest hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_1-fiv_6 k1_1-k1_6 k1_0

/* Table A11 - 3 Nearest Neighbors */
psmatch2 cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6, out(soudure) n(3) ate cal(.01) ai(3)
pstest hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_1-fiv_6 k1_1-k1_6 k1_0

/* Table A12 - 3 Nearest Neighbors with smaller caliper*/
psmatch2 cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6, out(soudure) n(3) cal(.001) ate ai(3)
pstest hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_1-fiv_6 k1_1-k1_6 k1_0


* Referee-Requested Stuff *
* Hausman Test *

reg cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight]
predict e, resid
reg soudure cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 e [pweight=weight]
test e

reg soudure cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6
est store A
reg soudure cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6
est store B
hausman A B

reg soudure cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight]
test k1_1 k1_2 k1_3 k1_4 k1_5 k1_6


* Is Our Result Driven by Food Crops? *

xi: reg soudure cf cf_rice_crop_share hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight]
stcox cf cf_rice_crop_share hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6
streg cf cf_rice_crop_share hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6, dist(weibull)

xi: reg soudure cf cf_food_crop_share hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight]
stcox cf cf_food_crop_share hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6
streg cf cf_food_crop_share hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6, dist(weibull)


xi: reg soudure cf cf_rice_crop_share hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 [pweight=weight]
stcox cf cf_rice_crop_share hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6
streg cf cf_rice_crop_share hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6, dist(weibull)

xi: reg soudure cf cf_food_crop_share hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 [pweight=weight]
stcox cf cf_food_crop_share hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6
streg cf cf_food_crop_share hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6, dist(weibull)


* Are There Other Kinds of Treatment Heterogeneity? *

rename adulteq14to64 adult_eq

gen cf_hhsize = cf*hhsize
gen cf_adult_eq = cf*adult_eq

xi: reg soudure cf cf_hhsize hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 [pweight=weight]

xi: reg soudure cf cf_adult_eq adult_eq depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 [pweight=weight]


gen cf_depr = cf*depr
gen cf_single = cf*single
gen cf_female = cf*female
gen cf_migrant = cf*migrant
gen cf_age = cf*age
gen cf_educ = cf*educ
gen cf_ag_exp = cf*ag_exp
gen cf_farm_org = cf*farm_org
gen cf_fady = cf*fady
gen cf_income = cf*income
gen cf_assets = cf*assets
gen cf_wrk_cap = cf*wrk_cap
gen cf_land_tot = cf*land_tot

xi: reg soudure cf cf_hhsize hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]
xi: reg soudure cf cf_depr hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]
xi: reg soudure cf cf_single hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]
xi: reg soudure cf cf_female hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]
xi: reg soudure cf cf_migrant hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]
xi: reg soudure cf cf_age hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]
xi: reg soudure cf cf_educ hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]
xi: reg soudure cf cf_ag_exp hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]
xi: reg soudure cf cf_farm_org hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]
xi: reg soudure cf cf_fady hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]
xi: reg soudure cf cf_income hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]
xi: reg soudure cf cf_assets hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]
xi: reg soudure cf cf_wrk_cap hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]
xi: reg soudure cf cf_land_tot hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]

* Focusing on What Is Significant

xi: reg soudure cf cf_hhsize hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]
xi: reg soudure cf cf_depr hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]
xi: reg soudure cf cf_age hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]

gen cf_adults_m = cf*dem_m_15_64 
gen cf_elderly_m = cf*dem_m_65_up 
gen cf_adults_f = cf*dem_f_15_64 
gen cf_elderly_f = cf*dem_f_65_up

xi: reg soudure cf cf_kids_m cf_adults_m cf_elderly_m cf_kids_f cf_adults_f cf_elderly_f hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6[pweight=weight]

